==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/servicebus/kotlin/inputs/GetRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicebus.kotlin.inputs

import com.pulumi.azurenative.servicebus.inputs.GetRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property namespaceName The namespace name
 * @property resourceGroupName Name of the Resource group within the Azure subscription.
 * @property ruleName The rule name.
 * @property subscriptionName The subscription name.
 * @property topicName The topic name.
 */
public data class GetRulePlainArgs(
    public val namespaceName: String,
    public val resourceGroupName: String,
    public val ruleName: String,
    public val subscriptionName: String,
    public val topicName: String,
) : ConvertibleToJava<com.pulumi.azurenative.servicebus.inputs.GetRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.servicebus.inputs.GetRulePlainArgs =
        com.pulumi.azurenative.servicebus.inputs.GetRulePlainArgs.builder()
            .namespaceName(namespaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleName(ruleName.let({ args0 -> args0 }))
            .subscriptionName(subscriptionName.let({ args0 -> args0 }))
            .topicName(topicName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetRulePlainArgs].
 */
@PulumiTagMarker
public class GetRulePlainArgsBuilder internal constructor() {
    private var namespaceName: String? = null

    private var resourceGroupName: String? = null

    private var ruleName: String? = null

    private var subscriptionName: String? = null

    private var topicName: String? = null

    /**
     * @param value The namespace name
     */
    @JvmName("kjjmxijdbmahtfde")
    public suspend fun namespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.namespaceName = mapped
    }

    /**
     * @param value Name of the Resource group within the Azure subscription.
     */
    @JvmName("tfyuqchabaoyyyuo")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The rule name.
     */
    @JvmName("lqrvriafnodyhrtn")
    public suspend fun ruleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleName = mapped
    }

    /**
     * @param value The subscription name.
     */
    @JvmName("gpqjtaskdphwfati")
    public suspend fun subscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.subscriptionName = mapped
    }

    /**
     * @param value The topic name.
     */
    @JvmName("tqfappvflelcjloj")
    public suspend fun topicName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.topicName = mapped
    }

    internal fun build(): GetRulePlainArgs = GetRulePlainArgs(
        namespaceName = namespaceName ?: throw PulumiNullFieldException("namespaceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        ruleName = ruleName ?: throw PulumiNullFieldException("ruleName"),
        subscriptionName = subscriptionName ?: throw PulumiNullFieldException("subscriptionName"),
        topicName = topicName ?: throw PulumiNullFieldException("topicName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicebus/kotlin/inputs/GetRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicebus.kotlin.inputs

import com.pulumi.azurenative.servicebus.inputs.GetRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property namespaceName The namespace name
 * @property resourceGroupName Name of the Resource group within the Azure subscription.
 * @property ruleName The rule name.
 * @property subscriptionName The subscription name.
 * @property topicName The topic name.
 */
public data class GetRulePlainArgs(
    public val namespaceName: String,
    public val resourceGroupName: String,
    public val ruleName: String,
    public val subscriptionName: String,
    public val topicName: String,
) : ConvertibleToJava<com.pulumi.azurenative.servicebus.inputs.GetRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.servicebus.inputs.GetRulePlainArgs =
        com.pulumi.azurenative.servicebus.inputs.GetRulePlainArgs.builder()
            .namespaceName(namespaceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleName(ruleName.let({ args0 -> args0 }))
            .subscriptionName(subscriptionName.let({ args0 -> args0 }))
            .topicName(topicName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetRulePlainArgs].
 */
@PulumiTagMarker
public class GetRulePlainArgsBuilder internal constructor() {
    private var namespaceName: String? = null

    private var resourceGroupName: String? = null

    private var ruleName: String? = null

    private var subscriptionName: String? = null

    private var topicName: String? = null

    /**
     * @param value The namespace name
     */
    @JvmName("hlaeacfvmmwqgenw")
    public suspend fun namespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.namespaceName = mapped
    }

    /**
     * @param value Name of the Resource group within the Azure subscription.
     */
    @JvmName("fdpccareswhehdgu")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The rule name.
     */
    @JvmName("hwtwjswqlkomegxi")
    public suspend fun ruleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleName = mapped
    }

    /**
     * @param value The subscription name.
     */
    @JvmName("fcuhijeourekdfgp")
    public suspend fun subscriptionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.subscriptionName = mapped
    }

    /**
     * @param value The topic name.
     */
    @JvmName("kqrfuormplayycwf")
    public suspend fun topicName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.topicName = mapped
    }

    internal fun build(): GetRulePlainArgs = GetRulePlainArgs(
        namespaceName = namespaceName ?: throw PulumiNullFieldException("namespaceName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        ruleName = ruleName ?: throw PulumiNullFieldException("ruleName"),
        subscriptionName = subscriptionName ?: throw PulumiNullFieldException("subscriptionName"),
        topicName = topicName ?: throw PulumiNullFieldException("topicName"),
    )
}
